"""
Utility functions for Solveig.

This module provides helper functions for:
- File I/O operations with metadata
- Terminal formatting and user interaction
- Output processing and display
"""

from solveig.utils import misc

__all__ = ["misc"]
